[![Build Status](https://travis-ci.com/score-p/scorep_binding_python_dummy.svg?branch=master)](https://travis-ci.com/score-p/scorep_binding_python_dummy)

# scorep-dummy
This module is a dummy module for https://github.com/score-p/scorep_binding_python . The goal is to provid a package that only keeps the user interface and does nothing.  
